[−][src]Struct mdbook::config::Search
Configuration of the search functionality of the HTML renderer.
Fields
enable: boolEnable the search feature. Default: true.
limit_results: u32Maximum number of visible results. Default: 30.
The number of words used for a search result teaser. Default: 30.
use_boolean_and: boolDefine the logical link between multiple search words.
If true, all search words must appear in each result. Default: false.
boost_title: u8Boost factor for the search result score if a search word appears in the header.
Default: 2.
boost_hierarchy: u8Boost factor for the search result score if a search word appears in the hierarchy.
The hierarchy contains all titles of the parent documents and all parent headings.
Default: 1.
boost_paragraph: u8Boost factor for the search result score if a search word appears in the text.
Default: 1.
expand: boolTrue if the searchword micro should match microwave. Default: true.
heading_split_level: u8Documents are split into smaller parts, seperated by headings. This defines, until which
level of heading documents should be split. Default: 3. (### This is a level 3 heading)
copy_js: boolCopy JavaScript files for the search functionality to the output directory?
Default: true.